@@ -96,9 +96,14 @@ if ($cpan) {
 
 find(
     sub {
+        if (-d) {
+          my @parts = File::Spec->splitdir($File::Find::name);
+          # be careful not to skip inc::latest
+          return $File::Find::prune = 1 if @parts == 3 and ($parts[-1] eq 'inc' or $parts[-1] eq 't');
+        }
+
         /(\.pm|_pm\.PL)$/ or return;
         /PPPort\.pm$/ and return;
-        /__Storable__\.pm$/ and return;
         my $module = $File::Find::name;
         $module =~ /\b(demo|t|private|corpus)\b/ and return;    # demo or test modules
         my $version = MM->parse_version($_);
@@ -106,7 +111,7 @@ find(
         $version =~ /\d/ and $version = "'$version'";
 
         # some heuristics to figure out the module name from the file name
-        $module =~ s{^(lib|cpan|dist|(?:symbian/)?ext|os2/OS2)/}{}
+        $module =~ s{^(lib|cpan|dist|ext|os2/OS2)/}{}
 			and $1 ne 'lib'
             and (
             $module =~ s{\b(\w+)/\1\b}{$1},
@@ -131,7 +136,6 @@ find(
         $module_to_file{$module} = $File::Find::name;
     },
     'os2/OS2',
-    'symbian/ext',
     'lib',
     'ext',
 	'cpan',
@@ -292,7 +296,9 @@ foreach my $module ( sort keys %module_to_upstream ) {
     $bug_tracker = $bug_tracker->{web} if ref($bug_tracker) eq "HASH";
 
     $bug_tracker = defined $bug_tracker ? quote($bug_tracker) : 'undef';
+    next if $bug_tracker eq "'https://github.com/Perl/perl5/issues'";
 	next if $bug_tracker eq "'http://rt.perl.org/perlbug/'";
+	next if $bug_tracker eq "'https://rt.perl.org/perlbug/'";
     $tracker .= sprintf "    %-24s=> %s,\n", "'$module'", $bug_tracker;
 }
 $tracker .= ");";
