@@ -2,13 +2,14 @@ package ExtUtils::Command;
 
 use 5.00503;
 use strict;
+use warnings;
 require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 @ISA       = qw(Exporter);
 @EXPORT    = qw(cp rm_f rm_rf mv cat eqtime mkpath touch test_f test_d chmod
                 dos2unix);
-$VERSION = '7.30';
-$VERSION = eval $VERSION;
+$VERSION = '7.60';
+$VERSION =~ tr/_//d;
 
 my $Is_VMS   = $^O eq 'VMS';
 my $Is_VMS_mode = $Is_VMS;
