@@ -1,14 +1,15 @@
 package ExtUtils::MM_Darwin;
 
 use strict;
+use warnings;
 
 BEGIN {
     require ExtUtils::MM_Unix;
     our @ISA = qw( ExtUtils::MM_Unix );
 }
 
-our $VERSION = '7.34';
-$VERSION = eval $VERSION;
+our $VERSION = '7.60';
+$VERSION =~ tr/_//d;
 
 
 =head1 NAME
@@ -21,7 +22,7 @@ ExtUtils::MM_Darwin - special behaviors for OS X
 
 =head1 DESCRIPTION
 
-See L<ExtUtils::MM_Unix> for L<ExtUtils::MM_Any> for documentation on the
+See L<ExtUtils::MM_Unix> or L<ExtUtils::MM_Any> for documentation on the
 methods overridden here.
 
 =head2 Overridden Methods
@@ -45,4 +46,29 @@ sub init_dist {
     $self->SUPER::init_dist(@_);
 }
 
+=head3 cflags
+
+Over-ride Apple's automatic setting of -Werror
+
+=cut
+
+sub cflags {
+    my($self,$libperl)=@_;
+    return $self->{CFLAGS} if $self->{CFLAGS};
+    return '' unless $self->needs_linking();
+
+    my $base = $self->SUPER::cflags($libperl);
+
+    foreach (split /\n/, $base) {
+        /^(\S*)\s*=\s*(\S*)$/ and $self->{$1} = $2;
+    };
+    $self->{CCFLAGS} .= " -Wno-error=implicit-function-declaration";
+
+    return $self->{CFLAGS} = qq{
+CCFLAGS = $self->{CCFLAGS}
+OPTIMIZE = $self->{OPTIMIZE}
+PERLTYPE = $self->{PERLTYPE}
+};
+}
+
 1;
