@@ -187,6 +187,7 @@ d_gdbm_ndbm_h_uses_prototypes='undef'
 d_gdbmndbm_h_uses_prototypes='undef'
 d_getaddrinfo='undef'
 d_getcwd='undef'
+d_getenv_preserves_other_thread='define'
 d_getespwnam='undef'
 d_getfsstat='undef'
 d_getgrent='undef'
@@ -874,11 +875,11 @@ uidsign='1'
 uidsize='4'
 uidtype=int
 uquadtype='uint64_t'
-use5005threads='undef'
 use64bitall='undef'
 use64bitint='undef'
 usecbacktrace='undef'
 usecrosscompile='undef'
+usedefaultstrict='undef'
 usedevel='undef'
 usedl='undef'
 usedtrace='undef'
